/*
  GP2X minimal library by rlyeh, (c) 2005. emulnation.info@rlyeh (swap it!)

  License
  =======

  Free for non-commercial projects (it would be nice receiving a mail from you).
  Other cases, ask me first.

  GamePark Holdings is not allowed to use this library and/or use parts from it.

  ------------------------------------------------------------------------------

  This is a program example which uses both GP2X 920t/940t processors.

  Usage:

  - Declare the subprogram name by using gp2x_dualcore_declare_subprogram(name)
    Note that this name must match with the specified one at your 940t subprogram.

  - You can access the GP2X memory through gp2x_dualcore_data() macro.

  - Launch a subprogram by using gp2x_dualcore_launch_subprogram(name) function.


  If you want to use the featured FIFO message system between both cores,
  you have to send commands to the 940t core through the gp2x_dualcore_exec(command)
  function. Use gp2x_dualcore_sync() to wait the 940t to finish all its requests.

  If you want a subprogram to be at background and not to sync with the 920t core
  just launch the subprogram and leave it working. Note that in this case the 940t
  main() function should not return, as specified in 940t.c sample file.
*/

#include "minimal.h"
#include "our_shared_data.h"


gp2x_dualcore_declare_subprogram(940t);   //declare our first  subprogram


int main(int argc, char *argv[])
{
 gp2x_init(1000, 16, 11025,16,1,60);

 gp2x_dualcore_launch_subprogram(940t);

 printf("Dual CPU test (compiled "__DATE__" " __TIME__")\n\n");

 printf("Test 1: Setting mem to 1 and executing our command INVERT at 2nd cpu...\n");
 VARIABLE_A=1;
 gp2x_dualcore_exec(MESSAGE_INVERT);

 printf("Test 1: Waiting for the 2nd core to finish its task...\n");
 gp2x_dualcore_sync();

 printf("Test 1: Current value of mem is %lu (should be 0)\n\n",VARIABLE_A);


 printf("Test 2: Setting mem to 23 and executing our command SUBTRACT at 2nd cpu...\n");
 VARIABLE_B=23;
 gp2x_dualcore_exec(MESSAGE_SUBTRACT);

 printf("Test 2: Doing something with the 1st core while the 2nd one finishes its task...\n");

 { int i; for(i=0;i<1000000;i++); }

 printf("Test 2: Current value of mem is %lu (should be 22)\n\n",VARIABLE_B);
                                                           

 printf("Test 3: Number of tests %lu (should be 2)\n",VARIABLE_TESTS);

 return 0;
}

void gp2x_sound_frame(void *blah, void *buff, int samples) {}



/*
compilation:

arm-linux-gcc minimal.c 920t.c 940t.c -static -lpthread

output through ext cable:

Dual CPU test

Test 1: Setting mem to 1 and executing our command at 2nd cpu...
Test 1: Waiting for the 2nd core to finish its task...
Test 1: Current value of mem is 0 (should be 0)

Test 2: Setting mem to 23 and executing our command at 2nd cpu...
Test 2: Doing something with the 1st core while the 2nd one finishes its task...
Test 2: Current value of mem is 22 (should be 22)

Test 3: Number of tests 2 (should be 2)
*/
